@@ -40,11 +40,11 @@ fn test_crawl_trade_all(market_type: MarketType) {
 }
 
 #[test_case(MarketType::Spot, "BTC-USDT")]
-#[test_case(MarketType::InverseFuture, "BTC-USD-210924")]
-#[test_case(MarketType::LinearFuture, "BTC-USDT-210924")]
+#[test_case(MarketType::InverseFuture, "BTC-USD-211231")]
+#[test_case(MarketType::LinearFuture, "BTC-USDT-211231")]
 #[test_case(MarketType::InverseSwap, "BTC-USD-SWAP")]
 #[test_case(MarketType::LinearSwap, "BTC-USDT-SWAP")]
-#[test_case(MarketType::EuropeanOption, "BTC-USD-210924-18000-P"; "inconclusive")]
+#[test_case(MarketType::EuropeanOption, "BTC-USD-211231-18000-P"; "inconclusive")]
 fn test_crawl_trade(market_type: MarketType, symbol: &str) {
     gen_test_code!(
         crawl_trade,
@@ -56,11 +56,11 @@ fn test_crawl_trade(market_type: MarketType, symbol: &str) {
 }
 
 #[test_case(MarketType::Spot, "BTC-USDT")]
-#[test_case(MarketType::InverseFuture, "BTC-USD-210924")]
-#[test_case(MarketType::LinearFuture, "BTC-USDT-210924")]
+#[test_case(MarketType::InverseFuture, "BTC-USD-211231")]
+#[test_case(MarketType::LinearFuture, "BTC-USDT-211231")]
 #[test_case(MarketType::InverseSwap, "BTC-USD-SWAP")]
 #[test_case(MarketType::LinearSwap, "BTC-USDT-SWAP")]
-#[test_case(MarketType::EuropeanOption, "BTC-USD-210924-18000-P")]
+#[test_case(MarketType::EuropeanOption, "BTC-USD-211231-18000-P")]
 fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
     gen_test_code!(
         crawl_l2_event,
@@ -72,11 +72,11 @@ fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
 }
 
 #[test_case(MarketType::Spot, "BTC-USDT")]
-#[test_case(MarketType::InverseFuture, "BTC-USD-210924")]
-#[test_case(MarketType::LinearFuture, "BTC-USDT-210924")]
+#[test_case(MarketType::InverseFuture, "BTC-USD-211231")]
+#[test_case(MarketType::LinearFuture, "BTC-USDT-211231")]
 #[test_case(MarketType::InverseSwap, "BTC-USD-SWAP")]
 #[test_case(MarketType::LinearSwap, "BTC-USDT-SWAP")]
-#[test_case(MarketType::EuropeanOption, "BTC-USD-210924-18000-P")]
+#[test_case(MarketType::EuropeanOption, "BTC-USD-211231-18000-P")]
 fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
     gen_test_snapshot_code!(
         crawl_l2_snapshot,
@@ -87,6 +87,21 @@ fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
     )
 }
 
+#[test_case(MarketType::Spot)]
+#[test_case(MarketType::InverseFuture)]
+#[test_case(MarketType::LinearFuture)]
+#[test_case(MarketType::InverseSwap)]
+#[test_case(MarketType::LinearSwap)]
+#[test_case(MarketType::EuropeanOption)]
+fn test_crawl_l2_snapshot_without_symbol(market_type: MarketType) {
+    gen_test_snapshot_without_symbol_code!(
+        crawl_l2_snapshot,
+        EXCHANGE_NAME,
+        market_type,
+        MessageType::L2Snapshot
+    )
+}
+
 #[test_case(MarketType::InverseSwap, "BTC-USD-SWAP")]
 #[test_case(MarketType::LinearSwap, "BTC-USDT-SWAP")]
 fn test_crawl_funding_rate(market_type: MarketType, symbol: &str) {
@@ -100,11 +115,11 @@ fn test_crawl_funding_rate(market_type: MarketType, symbol: &str) {
 }
 
 #[test_case(MarketType::Spot, "BTC-USDT")]
-#[test_case(MarketType::InverseFuture, "BTC-USD-210924")]
-#[test_case(MarketType::LinearFuture, "BTC-USDT-210924")]
+#[test_case(MarketType::InverseFuture, "BTC-USD-211231")]
+#[test_case(MarketType::LinearFuture, "BTC-USDT-211231")]
 #[test_case(MarketType::InverseSwap, "BTC-USD-SWAP")]
 #[test_case(MarketType::LinearSwap, "BTC-USDT-SWAP")]
-#[test_case(MarketType::EuropeanOption, "BTC-USD-210924-18000-P")]
+#[test_case(MarketType::EuropeanOption, "BTC-USD-211231-18000-P")]
 fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
     gen_test_code!(
         crawl_ticker,
